<?php

namespace WPTranslation\Api;

use Exception;
use WPTranslation\Utils\Settings;
use WPTranslation\Vendors\Illuminate\Support\Arr;

class Gumroad
{
    /**
     * The gumroad api endpoint
     *
     * @var string
     */
    private string $endpoint = "https://api.gumroad.com/v2";

    /**
     * The product id
     *
     * @var string
     */
    private string $productId;

    /**
     * The licence key
     *
     * @var string
     */
    private ?string $licenceKey;

    /**
     * Create a new Gumroad API client
     *
     * @param string|null $key
     * @throws Exception
     */
    public function __construct(string $key = null)
    {
        // get the key
        if (empty($key)) {
            $key = Settings::get("license.key");
        }
        $this->licenceKey = $key;

        if (defined("WPTRANSLATION_GUMROAD_PRODUCT_ID")) {
            $this->productId = WPTRANSLATION_GUMROAD_PRODUCT_ID;
        }
    }

    /**
     * Call the verify licence api from gumroad
     *
     * @return array
     * @throws Exception
     */
    public function verifyLicence(): array
    {
        if (empty($this->licenceKey)) {
            return ["success" => false];
        }
        // call the verify licence api
        return $this->request("POST", "licenses/verify", [
            "body" => [
                "product_id" => $this->productId,
                "license_key" => $this->licenceKey,
                "increment_uses_count" => "false"
            ]
        ]);
    }

    /**
     * Perform an api request
     *
     * @param string $method
     * @param string $uri
     * @param array $options
     * @return array
     * @throws Exception
     */
    private function request(string $method, string $uri, array $options = [])
    {
        $url = rtrim($this->endpoint, '/') . '/' . ltrim($uri, '/');
        $args = [
            "method" => $method,
        ];


        $args = array_merge($args, $options);

        $response = wp_remote_request($url, $args);

        $body = Arr::get($response, "body");

        return json_decode($body, true);
    }
}
