<?php

namespace WPTranslation\Api;

use Exception;
use WPTranslation\Utils\Settings;
use WPTranslation\Vendors\Illuminate\Support\Arr;

class OpenAI
{
    /**
     * The openai api endpoint
     *
     * @var string
     */
    private string $endpoint = "https://api.openai.com/v1";

    /**
     * The openai api key
     *
     * @var string
     */
    private string $key;

    /**
     * Create a new OpenAI API client
     *
     * @param string|null $key
     * @throws Exception
     */
    public function __construct(string $key = null)
    {
        // get the key
        if (empty($key)) {
            $key = Settings::get("api.openai.key");
        }
        if (empty($key)) {
            throw new Exception("No OpenAI API Key provided.");
        }
        $this->key = $key;

        // // create the http client
        // $settings = [
        //     "base_uri" => rtrim($this->endpoint, "/") . '/',
        //     "headers" => [
        //         "Authorization" => "Bearer " . $key,
        //         "Content-Type" => "application/json",
        //     ],
        //     "timeout" => 600
        // ];

        // if (!empty($organization)) {
        //     $settings["headers"]["OpenAI-Organization"] = $organization;
        // }

        // $this->client = new HttpClient($settings);
    }

    /**
     * Call the list models api from openai
     *
     * @return array
     * @throws Exception
     */
    public function listModels(): array
    {
        return $this->request("GET", "models");
    }

    /**
     * Call the chat api from openai
     *
     * @param array $payload
     * @return array
     * @throws Exception
     */
    public function chat(array $payload): array
    {
        // call the chat api
        $complete = $this->request("POST", "chat/completions", [
            "body" => json_encode($payload)
        ]);

        return $complete;
    }

    /**
     * Perform an api request
     *
     * @param string $method
     * @param string $uri
     * @param array $options
     * @return array
     * @throws Exception
     */
    private function request(string $method, string $uri, array $options = [])
    {
        $url = rtrim($this->endpoint, '/') . '/' . ltrim($uri, '/');
        $args = [
            "method" => $method,
            "headers" => [
                "Authorization" => "Bearer " . $this->key,
                "Content-Type" => "application/json",
            ],
            "timeout" => 600,
        ];

        $args = array_merge($args, $options);

        $response = wp_remote_request($url, $args);
        $body = Arr::get($response, "body");

        return json_decode($body, true);
    }
}
