<?php

namespace WPTranslation\Controllers;

use WPTranslation\Vendors\Illuminate\Pagination\LengthAwarePaginator;
use WPTranslation\Vendors\Illuminate\Support\Arr;

class TranslationsController extends Controller
{
    private $perPage = 50;

    public function index()
    {
        global $wpdb;

        $this->verifyNonce();

        $this->validate([
            "page" => ["nullable", "numeric"],
            "per_page" => ["nullable", "numeric"],
            "status" => ["nullable", "string"],
        ]);

        $page = Arr::get($this->request, "page", 1);
        $perPage = Arr::get($this->request, "per_page", $this->perPage);

        // get translations
        $sql = "SELECT * FROM `" . $wpdb->prefix . "wpt_translations`";
        if (!empty($status = Arr::get($this->request, "status"))) {
            $sql = $sql . " WHERE `status` = \"" . $status . "\"";
        }
        $totalSql = "SELECT COUNT(1) FROM (" . $sql . ") AS `combined_table`";
        $total = $wpdb->get_var($totalSql);

        $sql = $sql . " ORDER BY `created_at` DESC";
        $sql = $sql . " LIMIT " . $perPage . " OFFSET " . (($page - 1) * $perPage);
        $translations = $wpdb->get_results($sql, ARRAY_A);

        // get posts
        if (!empty($translations)) {
            $postIds = Arr::pluck($translations, "post_id");
            $postIds = array_values(array_filter($postIds));
            $posts = [];

            if (!empty($postIds)) {
                $sql = "SELECT ID, post_title FROM `" . $wpdb->prefix . "posts` WHERE `ID` IN (" . implode(",", $postIds) . ")";
                $posts = $wpdb->get_results($sql, ARRAY_A);
                $posts = Arr::keyBy($posts, "ID");
            }

            $translations = array_map(function ($translation) use ($posts) {
                if (empty($translation["post_id"])) {
                    $translation["post"] = null;
                    return $translation;
                }

                $post = Arr::get($posts, $translation["post_id"], null);
                if (!empty($post)) {
                    $post["display_link"] = get_permalink($post['ID']);
                }
                $translation["post"] = $post;

                return $translation;
            }, $translations);
        }

        // get translated posts
        if (!empty($translations)) {
            $postIds = Arr::pluck($translations, "translated_post_id");
            $postIds = array_values(array_filter($postIds));
            $posts = [];

            if (!empty($postIds)) {
                $sql = "SELECT ID, post_title FROM `" . $wpdb->prefix . "posts` WHERE `ID` IN (" . implode(",", $postIds) . ")";
                $posts = $wpdb->get_results($sql, ARRAY_A);
                $posts = Arr::keyBy($posts, "ID");
            }

            $translations = array_map(function ($translation) use ($posts) {
                if (empty($translation["translated_post_id"])) {
                    $translation["translated_post"] = null;
                    return $translation;
                }

                $post = Arr::get($posts, $translation["translated_post_id"], null);
                if (!empty($post)) {
                    $post["display_link"] = get_permalink($post['ID']);
                }
                $translation["translated_post"] = $post;

                return $translation;
            }, $translations);
        }

        // pagination
        $paginator = new LengthAwarePaginator($translations, $total, $perPage, $page);

        $this->response($paginator->toArray());
    }
}
