<?php

namespace WPTranslation\Controllers;

use WPTranslation\Vendors\Illuminate\Support\Arr;

class WordpressController extends Controller
{
    public function users()
    {
        $this->verifyNonce();

        $this->response(array_map(function ($user) {

            return [
                'id' => $user->ID,
                'name' => $user->display_name,
            ];
        }, get_users()));
    }

    public function categories()
    {
        $this->verifyNonce();

        $this->response(array_values(get_categories(["hide_empty" => true])));
    }

    public function productCategories()
    {
        $this->verifyNonce();

        $this->response(array_values(get_categories(["taxonomy" => "product_cat", "hide_empty" => true])));
    }

    public function postTypes()
    {
        $this->verifyNonce();

        $postTypes = get_post_types([], 'objects');

        $postTypes = array_filter($postTypes, function ($postType) {
            if (function_exists('pll_is_translated_post_type')) {
                return pll_is_translated_post_type($postType->name);
            }
            return true;
        });

        $postTypes = array_filter($postTypes, function ($postType) {
            return !in_array($postType->name, ["shop_order", "wp_block"]);
        });

        $postTypes = array_values($postTypes);

        $postTypes = array_map(function ($postType) {
            return ["id" => $postType->name, "name" => $postType->labels->singular_name];
        }, $postTypes);

        $this->response($postTypes);
    }

    public function customFields()
    {
        global $wpdb;

        $this->verifyNonce();

        $tableName = $wpdb->prefix . "postmeta";
        $results = $wpdb->get_results("SELECT DISTINCT(meta_key) FROM $tableName ORDER BY meta_key ASC;", ARRAY_A);
        $metadata = Arr::pluck($results, "meta_key");

        foreach ($metadata as $key => $value) {
            if (is_protected_meta($metadata[$key], 'post')) {
                unset($metadata[$key]);
            }
        }

        $this->response(array_values($metadata));
    }
}
