<?php

namespace WPTranslation\Jobs;

use WPTranslation\Translator;

class TranslatePostJob extends Job
{
    private string $tableName;
    private ?array $translation;

    /**
     * Create a new job instance.
     */
    public function __construct(int $translationId)
    {
        global $wpdb;

        $this->tableName = $wpdb->prefix . "wpt_translations";
        $this->translation = $this->getTranslation($translationId);
    }

    /**
     * Execute the job.
     */
    public function handle()
    {
        global $polylang;

        if (empty($this->translation)) {
            return;
        }

        $this->setTranslationStatus("pending");

        // load WordPress Administration Bootstrap
        require_once ABSPATH . 'wp-admin/includes/admin.php';

        $translator = Translator::make($polylang);
        $post = $translator->duplicatePost($this->translation["post_id"], $this->translation["language"], true);

        if (empty($post)) {
            $this->setTranslationStatus("failed");
        } else {
            $this->setTranslatedPostId($post->ID);
            $this->setTranslationStatus("success");
        }
    }

    private function getTranslation(int $id): ?array
    {
        global $wpdb;

        return $wpdb->get_row("SELECT * from `" . $this->tableName . "` WHERE `id` = " . $id, ARRAY_A);
    }

    private function setTranslationStatus($status)
    {
        global $wpdb;

        if (empty($this->translation)) {
            return false;
        }

        return $wpdb->update($this->tableName, [
            "status" => $status
        ], [
            "id" => $this->translation['id']
        ]);
    }

    private function setTranslatedPostId($id)
    {
        global $wpdb;

        if (empty($this->translation)) {
            return false;
        }

        return $wpdb->update($this->tableName, [
            "translated_post_id" => $id
        ], [
            "id" => $this->translation['id']
        ]);
    }
}
