<?php

namespace WPTranslation\Utils;

use Exception;
use WPTranslation\Api\Gumroad;
use WPTranslation\Vendors\Illuminate\Support\Arr;
use WPTranslation\Vendors\Illuminate\Support\Carbon;

abstract class License
{
    const LICENSE_OPTION_NAME = "wptranslation_license";

    static public function isPremium()
    {
        return !empty(self::getLicence());
    }

    static function getLicence()
    {
        if (function_exists('get_option')) {
            $cache = get_option(self::LICENSE_OPTION_NAME, null);

            if (
                empty($cache) ||
                Carbon::createFromFormat(
                    "Y-m-d H:i:s",
                    Arr::get(
                        $cache,
                        "cached_at",
                        Carbon::now()->subMonth()
                    )
                )
                ->lt(
                    Carbon::now()->subMinutes(5)
                )
            ) {
                $api = new Gumroad();
                try {
                    $response = $api->verifyLicence();

                    if (Arr::get($response, "success", false)) {
                        $license = Arr::only(Arr::get($response, "purchase"), [
                            "seller_id",
                            "product_id",
                            "product_name",
                            "email",
                            "sale_timestamp",
                        ]);

                        $cache = [
                            "data" => $license,
                            "cached_at" => Carbon::now()->format("Y-m-d H:i:s"),
                        ];

                        self::updateCache($cache);

                        return $license;
                    } else {
                        self::removeLicense();
                    }
                } catch (Exception $e) {
                }

                return null;
            }

            return $cache["data"];
        }
    }

    static function updateCache($cache)
    {
        if (function_exists('update_option')) {
            update_option(self::LICENSE_OPTION_NAME, $cache, false);
        }
    }

    static function removeLicense()
    {
        if (function_exists('delete_option')) {
            delete_option(self::LICENSE_OPTION_NAME);
        }
    }
}
