<?php

namespace WPTranslation\Utils;

use WPTranslation\Vendors\Illuminate\Support\Arr;
use WPTranslation\Vendors\Illuminate\Support\Str;

class Linking
{
    protected array $cache = [];

    /**
     * transform link into translated post link
     *
     * @param string $content
     * @return string
     */
    public function run(string $content): string
    {
        // regex on all href link of the content
        $content = preg_replace_callback(
            '/<a.*href\s*=\s*["\'](.*?)["\'].*>/i',
            function ($matches) {
                $link = Arr::get($matches, 1);

                if (!empty($link)) {

                    // use cache if the link already has already been verified
                    if (isset($this->cache[$link])) {

                        // the link has a translated link
                        if (!empty($this->cache[$link])) {
                            return Str::replace($link, $this->cache[$link], $matches[0]);
                        }

                        return $matches[0];
                    }

                    // use WordPress url_to_postid function to determine the Post ID by url
                    $postId = url_to_postid($link);

                    // a post has been found
                    if (!empty($postId)) {

                        // polylang auto translate the get_permalink to matche the current language
                        // cache the permalink
                        $this->cache[$link] = get_permalink($postId);

                        return Str::replace($link, $this->cache[$link], $matches[0]);
                    }
                }

                // no translated link has been found
                $this->cache[$link] = null;

                return $matches[0];
            },
            $content
        );

        return $content;
    }

    static public function filter(string $content): string
    {
        if (!License::isPremium() || !Settings::get("convert_links.enabled", false)) {
            return $content;
        }

        $post = get_post();
        if (!empty($post)) {
            $linking = new self();
            return $linking->run($content);
        }

        return $content;
    }
}
