<?php

namespace WPTranslation\Utils;

use WPTranslation\Vendors\Illuminate\Support\Arr;

class Settings
{
    const OPTION_NAME = "polytranslate_settings";

    static private $data;
    static private $initialized = false;

    static private $defaults = [
        "license" => [
            "key" => ""
        ],
        "service" => "google-translate-free",
        "api" => [
            "deepl" => [
                "key" => "",
            ],
            "openai" => [
                "key" => "",
            ]
        ],
        "translation" => [
            "post_meta" => [
                "enabled" => false,
                "blacklist" => [],
            ],
            "terms" => [
                "enabled" => true,
            ],
            "yoast" => [
                "enabled" => true,
            ],
            "rank_math" => [
                "enabled" => true,
            ],
            "seopress" => [
                "enabled" => true,
            ]
        ],
        "concurrent_translations" => 5,
        "live" => [
            "enabled" => false,
            "languages" => [],
            "refresh" => false
        ],
        "convert_links" => [
            "enabled" => false,
        ],
        "use_background_tasks" => true,
        "concurrent_translations" => 5,
        "set_post_in_draft" => false,
    ];

    static public function get($key = null, $default = null)
    {
        if (!self::$initialized) {
            self::$data = get_option(self::OPTION_NAME, []);
            self::$data = array_replace_recursive(self::$defaults, self::$data);
            self::$initialized = true;
        }

        if ($key === null) {
            return self::$data;
        }
        return Arr::get(self::$data, $key, $default);
    }

    static public function update($value, $key = null)
    {
        $data = self::get();
        if ($key === null) {
            $data = $value;
        }
        Arr::set($data, $key, $value);

        self::$data = $data;

        return self::$data;
    }

    static public function save()
    {
        return update_option(self::OPTION_NAME, self::get(), true);
    }
}
